#/* Copyright 1998-2011 Research Foundation State University of New York */
#
#/* This file is part of QuB.                                            */
#
#/* QuB is free software; you can redistribute it and/or modify          */
#/* it under the terms of the GNU General Public License as published by */
#/* the Free Software Foundation, either version 3 of the License, or    */
#/* (at your option) any later version.                                  */
#
#/* QuB is distributed in the hope that it will be useful,               */
#/* but WITHOUT ANY WARRANTY; without even the implied warranty of       */
#/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
#/* GNU General Public License for more details.                         */
#
#/* You should have received a copy of the GNU General Public License,   */
#/* named LICENSE.txt, in the QuB program directory.  If not, see        */
#/* <http://www.gnu.org/licenses/>.                                      */

import QUB
import qubtree
from Buttons import *
from Dialogs import *

def SelEvts(props):
    sel_cls = props['cls'] - 1
    sel_min = props['min']
    sel_max = props['max']
    idl = QUB.getChosenIdealization().find('DataSet')
    if not idl.find('Segment').find('Classes').data:
        QUB.Report('No idealized data; check the Data Source')
        return
    samp = idl['sampling'].data[0]
    segs = []
    while not idl.find('Segment').isNull:
        seg = idl.find('Segment')
        segs.append(seg)
        idl.remove(seg)
    result = qubtree.Node('Result')
    result['ResultType'].data = 'SelEvts'
    rds = result.appendClone(idl)
    rseg = qubtree.NullNode()
    for seg in segs:
        start = seg['start'].data[0]
        idwt = seg['Classes'].data
        tdwt = seg['Durations'].data
        sdwt = seg['Firsts'].data
        edwt = seg['Lasts'].data
        for i in xrange(seg['DwellCount'].data[0]):
            if (idwt[i] == sel_cls) and (sel_min <= tdwt[i] <= sel_max):
                rseg = rds.insert('Segment', rseg)
                rseg.data = (sdwt[i], edwt[i])
                rseg['start'].data = start + samp * (sdwt[i] - seg.data[0])#
                rseg['length'].data = tdwt[i]
    if rseg.isNull:
        QUB.Report('No events found')
    else:
        QUB.ResultsView.addResults(result)
    
AddTaskButton( 'SelEvts', # button text
               SelEvts,   # function
               'SelEv',       # short text for small buttons
               1,            # show settings dialog on left-click?
               1,            # show settings dialog on right-click?
               "Select events by duration",   # tool-tip
               "Select events by duration",   # description in "Edit Buttons"
               "SelEvts settings:", # caption for the settings dialog
               [DialogText("cls", "Event class:", 1, acceptIntGreaterThan(0)),
                DialogText("min", "Min duration (ms):", 100.0, acceptFloat),
                DialogText("max", "Max duration (ms):", 1000.0, acceptFloat)],
               'Preprocessing' )
